===================================================
``psyclone.tests.psyir.backend.psyir_openacc_test``
===================================================

.. automodule:: psyclone.tests.psyir.backend.psyir_openacc_test

   .. contents::
      :local:

.. currentmodule:: psyclone.tests.psyir.backend.psyir_openacc_test
